summaryrefslogtreecommitdiff
path: root/src/sort.c
diff options
context:
space:
mode:
authorPádraig Brady <P@draigBrady.com>2015-10-15 15:15:56 +0100
committerPádraig Brady <P@draigBrady.com>2015-12-14 13:36:23 +0000
commitc609cd960d5cc309fe32ab315efe8dde79504d14 (patch)
tree8a214426f298e7b72bd558130a4c8483b14356cb /src/sort.c
parent5f87f1ac1cb2ef44aac4284d8103e7556597a842 (diff)
downloadcoreutils-c609cd960d5cc309fe32ab315efe8dde79504d14.tar.xz
maint: fix incorrect spellings etc
* NEWS: Use a standard version specification. * doc/coreutils.texi: Fix incorrect grammar. * src/df.c: Update a stale comment. * src/copy.c: Fix incorrect spellings. * src/factor.c: Likewise. * src/ls.c: Likewise. * src/pr.c: Likewise. * src/relpath.c: Likewise. * src/shred.c: Likewise. * src/sort.c: Likewise. * src/split.c: Likewise. * src/stdbuf.c: Likewise. * tests/misc/seq-precision.sh: Likewise.
Diffstat (limited to 'src/sort.c')
-rw-r--r--src/sort.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/sort.c b/src/sort.c
index 399b9644d..cf29727de 100644
--- a/src/sort.c
+++ b/src/sort.c
@@ -238,7 +238,7 @@ struct month
struct merge_node
{
struct line *lo; /* Lines to merge from LO child node. */
- struct line *hi; /* Lines to merge from HI child ndoe. */
+ struct line *hi; /* Lines to merge from HI child node. */
struct line *end_lo; /* End of available lines from LO. */
struct line *end_hi; /* End of available lines from HI. */
struct line **dest; /* Pointer to destination of merge. */
@@ -678,7 +678,7 @@ struct sortfile
/* The file's name. */
char const *name;
/* Nonnull if this is a temporary file, in which case NAME == TEMP->name. */
struct tempnode *temp;
};
@@ -2736,7 +2736,7 @@ compare (struct line const *a, struct line const *b)
}
/* Write LINE to output stream FP; the output file's name is
- OUTPUT_FILE if OUTPUT_FILE is nonnull, and is the standard output
+ OUTPUT_FILE if OUTPUT_FILE is non-null, and is the standard output
otherwise. If debugging is enabled and FP is standard output,
append some debugging information. */
@@ -678,7 +678,7 @@ struct sortfile
/* The file's name. */
char const *name;
- /* Nonnull if this is a temporary file, in which case NAME == TEMP->name. */
+ /* Non-null if this is a temporary file, in which case NAME == TEMP->name. */
struct tempnode *temp;
};